@@ -23,9 +23,11 @@
 #endif
 
 extern "C" {
-#include <libavformat/avformat.h>
-#include <libavutil/dict.h>
 #include <libavcodec/avcodec.h>
+#include <libavformat/avformat.h>
+#include <libavutil/avutil.h>
+#include <libavutil/dict.h>
+#include <libavutil/pixdesc.h>
 }
 
 using namespace KFileMetaData;
@@ -36,16 +38,17 @@ FFmpegExtractor::FFmpegExtractor(QObject* parent)
 }
 
 const QStringList supportedMimeTypes = {
+    QStringLiteral("video/mp2t"),
     QStringLiteral("video/mp4"),
     QStringLiteral("video/mpeg"),
-    QStringLiteral("video/quicktime"),
-    QStringLiteral("video/webm"),
     QStringLiteral("video/ogg"),
-    QStringLiteral("video/mp2t"),
+    QStringLiteral("video/quicktime"),
+    QStringLiteral("video/vnd.avi"),
+    QStringLiteral("video/webm"),
     QStringLiteral("video/x-flv"),
     QStringLiteral("video/x-matroska"),
-    QStringLiteral("video/x-ms-wmv"),
     QStringLiteral("video/x-ms-asf"),
+    QStringLiteral("video/x-ms-wmv"),
     QStringLiteral("video/x-msvideo"),
 };
 
@@ -58,7 +61,9 @@ void FFmpegExtractor::extract(ExtractionResult* result)
 {
     AVFormatContext* fmt_ctx = nullptr;
 
+#if LIBAVFORMAT_VERSION_MAJOR < 58
     av_register_all();
+#endif
 
     QByteArray arr = result->inputUrl().toUtf8();
 
@@ -87,11 +92,7 @@ void FFmpegExtractor::extract(ExtractionResult* result)
         if (index_stream >= 0) {
             AVStream* stream = fmt_ctx->streams[index_stream];
 
-#if defined HAVE_AVSTREAM_CODECPAR && HAVE_AVSTREAM_CODECPAR
             const AVCodecParameters* codec = stream->codecpar;
-#else
-            const AVCodecContext* codec = stream->codec;
-#endif
 
             if (codec->codec_type == AVMEDIA_TYPE_VIDEO) {
                 result->add(Property::Width, codec->width);
@@ -119,10 +120,33 @@ void FFmpegExtractor::extract(ExtractionResult* result)
                 if (frameRate) {
                     result->add(Property::FrameRate, frameRate);
                 }
+
+                result->add(Property::VideoCodec, QString::fromUtf8(avcodec_get_name(codec->codec_id)));
+
+                const AVPixFmtDescriptor *desc = av_pix_fmt_desc_get((AVPixelFormat)codec->format);
+                if (desc) {
+                    result->add(Property::PixelFormat, QString::fromUtf8(desc->name));
+                }
+
+                result->add(Property::ColorSpace, QString::fromUtf8(av_color_space_name(codec->color_space)));
             }
         }
+        
+        const auto audio_index_stream = av_find_best_stream(fmt_ctx, AVMEDIA_TYPE_AUDIO, -1, -1, nullptr, 0);
+        if (audio_index_stream >= 0) {
+            AVStream* stream = fmt_ctx->streams[audio_index_stream];
+
+            const AVCodecParameters* codec = stream->codecpar;
+            result->add(Property::AudioCodec, QString::fromUtf8(avcodec_get_name(codec->codec_id)));
+        }
 
         AVDictionary* dict = fmt_ctx->metadata;
+        // In Ogg, the internal comment metadata headers are attached to a single content stream.
+        // By convention, it's the first logical bitstream occuring.
+        if (!dict && fmt_ctx->nb_streams > 0) {
+            dict = fmt_ctx->streams[0]->metadata;
+        }
+
         AVDictionaryEntry* entry;
 
         entry = av_dict_get(dict, "title", nullptr, 0);
@@ -176,3 +200,5 @@ void FFmpegExtractor::extract(ExtractionResult* result)
 
     avformat_close_input(&fmt_ctx);
 }
+
+#include "moc_ffmpegextractor.cpp"
